@@ -69,11 +69,17 @@ class Actions(FileManagerAware, EnvironmentAware, SettingsAware):
 		"""Redraw the window"""
 		self.ui.redraw_window()
 
-	def open_console(self, mode=':', string='', prompt=None):
+	def open_console(self, mode=cmode.COMMAND, string='', prompt=None):
 		"""Open the console if the current UI supports that"""
 		if hasattr(self.ui, 'open_console'):
 			self.ui.open_console(mode, string, prompt=prompt)
 
+	def execute_console(self, string='', mode=cmode.COMMAND):
+		"""Execute a command for the console"""
+		self.open_console(mode=mode, string=string)
+		self.ui.console.line = string
+		self.ui.console.execute()
+
 	def execute_file(self, files, **kw):
 		"""Execute a file.
 		app is the name of a method in Applications, without the "app_"
@@ -140,7 +146,10 @@ class Actions(FileManagerAware, EnvironmentAware, SettingsAware):
 
 	def move_parent(self, n):
 		parent = self.env.at_level(-1)
-		self.env.enter_dir(parent.files[parent.pointer+n])
+		try:
+			self.env.enter_dir(parent.files[parent.pointer+n])
+		except IndexError:
+			pass
 
 	def history_go(self, relative):
 		"""Move back and forth in the history"""
